@@ -23,10 +23,9 @@ class Kuyruk(EventMixin):
 
         """
         super(Kuyruk, self).__init__()
+        self.config = Config()
         if config:
-            self.config = config
-        else:
-            self.config = Config()
+            self.config.from_object(config)
 
     def task(self, queue='kuyruk', eager=False, retry=0):
         """Wrap functions with this decorator to convert them to background
